@@ -51,14 +51,13 @@ echo "::endgroup::"
 
 echo "::group::Install packages for test"
 
-postgresql_version=$(dpkg -l | \
-                       grep pgroonga | \
-                       grep -E -o '[0-9.]+' |
-                       head -n1)
-postgresql_package_prefix=$(dpkg -l | \
-                              grep pgroonga | \
-                              grep -E -o 'postgresql-[0-9.]+(-pgdg)?' |
-                              head -n1)
+pgroonga_package=$(dpkg -l | \
+                     grep pgroonga | \
+                     head -n1 | \
+                     awk '{print $2}')
+postgresql_version=$(echo ${pgroonga_package} | grep -E -o '[0-9.]+')
+postgresql_package_prefix=$(echo ${pgroonga_package} | \
+                              grep -E -o 'postgresql-[0-9.]+(-pgdg)?')
 if ! echo "${postgresql_package_prefix}" | grep -q pgdg; then
   apt install -V -y \
       $(echo ${postgresql_package_prefix} | \
@@ -95,13 +94,12 @@ cp -a \
    /tmp/
 cd /tmp
 if [ ${postgresql_version} -lt 12 ]; then
-  rm sql/vacuum/two-phase-commit.sql
+  rm sql/function/highlight-html/declarative-partitioning.sql
+  rm sql/function/wal-set-applied-position/declarative-partitioning.sql
 fi
 if [ ${postgresql_version} -lt 13 ]; then
   rm sql/full-text-search/text/single/declarative-partitioning.sql
 fi
-# TODO: Remove this after Groonga 13.0.1 is released.
-rm sql/function/highlight-html/term-search.sql
 ruby /host/test/prepare.rb > schedule
 PG_REGRESS_DIFF_OPTS="-u"
 if diff --help | grep -q color; then
@@ -134,6 +132,19 @@ if [ ${pg_regress_status} -ne 0 ]; then
 fi
 
 
+echo "::group::Upgrade"
+
+sudo apt purge -V -y ${pgroonga_package}
+sudo apt install -V -y ${pgroonga_package}
+createdb upgrade
+psql upgrade -c 'CREATE EXTENSION pgroonga'
+apt install -V -y \
+  ${repositories_dir}/${os}/pool/${code_name}/*/*/*/*_${architecture}.deb
+psql upgrade -c 'ALTER EXTENSION pgroonga UPDATE'
+
+echo "::endgroup::"
+
+
 echo "::group::Postpare"
 
 sudo -u postgres -H \
